@@ -7,6 +7,7 @@ from inspect import isclass
 from django.core.exceptions import ImproperlyConfigured, FieldDoesNotExist
 from django.db.models import Q
 
+from .fields import SlickReportField
 from .helpers import get_field_from_query_text
 from .registry import field_registry
 
@@ -265,7 +266,7 @@ class ReportGenerator(object):
         return filters
 
     def _prepare_report_dependencies(self):
-        from .fields import BaseReportField
+        from .fields import SlickReportField
         all_columns = (
             ('normal', self._parsed_columns),
             ('time_series', self._time_series_parsed_columns),
@@ -275,7 +276,7 @@ class ReportGenerator(object):
             for col_data in window_cols:
                 klass = col_data['ref']
 
-                if isclass(klass) and issubclass(klass, BaseReportField):
+                if isclass(klass) and issubclass(klass, SlickReportField):
                     dependencies_names = klass.get_full_dependency_list()
 
                     # check if any of this dependencies is on the report
@@ -290,7 +291,7 @@ class ReportGenerator(object):
                 name = col_data['name']
 
                 # if column has a dependency then skip it
-                if not (isclass(klass) and issubclass(klass, BaseReportField)):
+                if not (isclass(klass) and issubclass(klass, SlickReportField)):
                     continue
                 if self._report_fields_dependencies[window].get(name, False):
                     continue
@@ -367,17 +368,32 @@ class ReportGenerator(object):
         data = [get_record_data(obj, all_columns) for obj in main_queryset]
         return data
 
-    def _parse(self):
+    @classmethod
+    def check_columns(cls, columns, group_by, report_model, ):
+        """
+        Check and parse the columns, throw errors in case an item in the columns cant not identified
+        :param columns: List of columns
+        :param group_by: group by field if any
+        :param report_model: the report model
+        :return: List of dict, each dict contains relevant data to the respective field in `columns`
+        """
+        group_by_model = None
+        if group_by:
+            group_by_field = [x for x in report_model._meta.fields if x.name == group_by][0]
+            group_by_model = group_by_field.related_model
 
-        if self.group_by:
-            self.group_by_field = [x for x in self.report_model._meta.fields if x.name == self.group_by][0]
-            self.group_by_model = self.group_by_field.related_model
+        parsed_columns = []
+        for col in columns:
+            magic_field_class = None
+            attr = None
+
+            if type(col) is str:
+                attr = getattr(cls, col, None)
+            elif issubclass(col, SlickReportField):
+                magic_field_class = col
 
-        self.parsed_columns = []
-        for col in self.columns:
-            attr = getattr(self, col, None)
             try:
-                magic_field_class = field_registry.get_field_by_name(col)
+                magic_field_class = magic_field_class or field_registry.get_field_by_name(col)
             except KeyError:
                 magic_field_class = None
 
@@ -395,7 +411,7 @@ class ReportGenerator(object):
                     #     These are placeholder not real computation field
                     continue
 
-                col_data = {'name': col,
+                col_data = {'name': magic_field_class.name,
                             'verbose_name': magic_field_class.verbose_name,
                             'source': 'magic_field',
                             'ref': magic_field_class,
@@ -404,7 +420,7 @@ class ReportGenerator(object):
                             }
             else:
                 # A database field
-                model_to_use = self.group_by_model if self.group_by else self.report_model
+                model_to_use = group_by_model if group_by else report_model
                 try:
                     if '__' in col:
                         # A traversing link order__client__email
@@ -413,7 +429,8 @@ class ReportGenerator(object):
                         field = model_to_use._meta.get_field(col)
                 except FieldDoesNotExist:
                     raise FieldDoesNotExist(
-                        f'Field "{col}" not found as an attribute to the generator class, nor as computation field, nor as a database column for the model "{model_to_use._meta.model_name}"')
+                        f'Field "{col}" not found either as an attribute to the generator class {cls}, '
+                        f'or a computation field, or a database column for the model "{model_to_use}"')
 
                 col_data = {'name': col,
                             'verbose_name': getattr(field, 'verbose_name', col),
@@ -421,11 +438,14 @@ class ReportGenerator(object):
                             'ref': field,
                             'type': field.get_internal_type()
                             }
-            self.parsed_columns.append(col_data)
+            parsed_columns.append(col_data)
+        return parsed_columns
 
-            self._parsed_columns = list(self.parsed_columns)
-            self._time_series_parsed_columns = self.get_time_series_parsed_columns()
-            self._crosstab_parsed_columns = self.get_crosstab_parsed_columns()
+    def _parse(self):
+        self.parsed_columns = self.check_columns(self.columns, self.group_by, self.report_model)
+        self._parsed_columns = list(self.parsed_columns)
+        self._time_series_parsed_columns = self.get_time_series_parsed_columns()
+        self._crosstab_parsed_columns = self.get_crosstab_parsed_columns()
 
     def get_database_columns(self):
         return [col['name'] for col in self.parsed_columns if col['source'] == 'database']
@@ -467,7 +487,13 @@ class ReportGenerator(object):
 
         for dt in series:
             for col in cols:
-                magic_field_class = field_registry.get_field_by_name(col)
+                magic_field_class = None
+
+                if type(col) is str:
+                    magic_field_class = field_registry.get_field_by_name(col)
+                elif issubclass(col, SlickReportField):
+                    magic_field_class = col
+
                 _values.append({
                     'name': col + 'TS' + dt[1].strftime('%Y%m%d'),
                     'original_name': col,
@@ -547,7 +573,12 @@ class ReportGenerator(object):
         ids_length = len(ids) - 1
         for counter, id in enumerate(ids):
             for col in report_columns:
-                magic_field_class = field_registry.get_field_by_name(col)
+                magic_field_class = None
+                if type(col) is str:
+                    magic_field_class = field_registry.get_field_by_name(col)
+                elif issubclass(col, SlickReportField):
+                    magic_field_class = col
+
                 output_cols.append({
                     'name': f'{col}CT{id}',
                     'original_name': col,
